"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tasks = void 0;
const amqplib_1 = __importDefault(require("amqplib"));
const index_1 = require("../index");
class Tasks {
    constructor(options) {
        this.running = 0;
        this.enabled = options.enabled;
        this.host = options.host;
    }
    start() {
        return new Promise((resolve, reject) => {
            if (!this.enabled)
                return resolve(null);
            try {
                amqplib_1.default.connect(`amqp://${this.host}`).then((con) => {
                    return con.createChannel().then((ch) => {
                        this.ch = ch;
                        this.con = con;
                        return resolve(this);
                    }).catch((ee) => {
                        reject(ee);
                    });
                }).catch((e) => {
                    reject(e);
                });
            }
            catch (e) {
                reject(e);
            }
        });
    }
    /* Send message to exchange abstraction */
    send(exchange, routeKey, message, options = {}) {
        if (!this.enabled)
            throw Error('Tasks feature is not enabled');
        let apmTransaction = null;
        if (index_1.apm)
            apmTransaction = index_1.apm.startTransaction(`${exchange} - ${routeKey}`, 'Rabbit');
        // Check if it's an object, if true convert to json
        const parsedMsg = (typeof message === 'object' && !Array.isArray(message)) ? JSON.stringify(message) : message;
        this.ch.assertExchange(exchange, options.type || 'direct', { durable: true });
        // Sends the message to the queue
        const status = this.ch.publish(exchange, routeKey, Buffer.from(parsedMsg));
        if (apmTransaction)
            apmTransaction.end();
        return status;
    }
    /* Listen to messages in the queue abstraction */
    async bindTask(task) {
        try {
            const ch = await index_1.tasks.con.createChannel(task);
            /* Debug */
            index_1.logger.debug(`Loading task ${task.exchange}/${task.queue}`, '');
            // TODO: Make each task a channel for better use of the prefetch
            ch.prefetch(task.prefetch || 1);
            /* Listen to messages in the queue abstraction */
            // Assert that this exchange exists
            task.options = task.options || {};
            const exchangeOptions = { durable: true, ...task.options };
            ch.assertExchange(task.exchange, task.type || 'direct', exchangeOptions);
            // Assert that the queue exists
            ch.assertQueue(task.queue);
            // Bind the queue in the exchange by the routing key
            ch.bindQueue(task.queue, task.exchange, task.routeKey);
            // Consumes it
            const consumerTag = `${Date.now()}${process.pid}${Math.random()}`;
            ch.consume(task.queue, (msg) => {
                index_1.counter.taskUp();
                try {
                    let apmTransaction = null;
                    // Check if APM is enabled to track the transaction
                    if (index_1.apm)
                        apmTransaction = index_1.apm.startTransaction(task.queue, 'Tasks');
                    // Lets threat the message
                    const stringMsg = msg.content.toString();
                    let parsedMsg;
                    // Tries to parse to object
                    try {
                        parsedMsg = JSON.parse(stringMsg);
                    }
                    catch (e) {
                        // If it fails send as a string
                        parsedMsg = stringMsg;
                    }
                    /**
                     * We send back to the user only a callback with the payload content and a done fuction
                     * so he can ack the message and possibly end the transaction.
                     * @return {type} Description.
                     */
                    task.action(parsedMsg, (nack, requeue = true, allUpTo = false) => {
                        // Check if APM is enabled to end the trasaction treacking
                        if (apmTransaction)
                            apmTransaction.end();
                        index_1.counter.taskDown();
                        if (typeof nack !== 'undefined') {
                            ch.nack(msg, allUpTo, requeue);
                            return;
                        }
                        // Sends the acknolage to the message at Rabbit
                        ch.ack(msg);
                    });
                }
                catch (e) {
                    index_1.counter.taskDown();
                }
            }, {
                consumerTag,
            });
            index_1.counter.consumerTags.push({ consumerTag, ch });
        }
        catch (e) {
            console.log(e);
        }
    }
}
exports.Tasks = Tasks;
//# sourceMappingURL=index.js.map