"use strict";
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeDeepOnTarget = exports.isSimpleObject = void 0;
/**
 * Checks if `value` is an object and if it's not an Array.
 *
 * @param value The value to check.
 * @returns Returns true if `value` is an object and if it's not an Array, else `false`.
 */
function isSimpleObject(value) {
    return value && typeof value === 'object' && !Array.isArray(value);
}
exports.isSimpleObject = isSimpleObject;
/**
 * Performs a deep merge (recursively) of objects from `source` to `target`.
 * Does modify objects and replace arrays.
 * Copies the values of all of the enumerable own properties from `source` to `target` object.
 *
 * @param target The target object to copy to.
 * @param source The source object from which to copy properties.
 * @example
 *
```
const target = {
  "a": 1,
  "b": 1,
  "c": { "x": 1, "y": 1 },
  "d": [ 1, 1 ],
  "f": "test",
  "g": [ "test1", "test2" ]
};
const source = {
  "b": 2,
  "c": { "y": 2, "z": 2 },
  "d": [ 2, 2 ],
  "e": 2,
  "f": null
};
const merged = mergeDeepOnTarget(target, source);

// Results
{
  "a": 1,
  "b": 2,
  "c": {
    "y": 2, "z": 2, "x": 1
  },
  "d": [ 2, 2 ],
  "e": 2,
  "f": null,
  "g": [ "test1", "test2" ]
}
 * ```
 */
function mergeDeepOnTarget(target, ...sources) {
    if (!sources.length)
        return target;
    const source = sources.shift();
    if (isSimpleObject(target) && isSimpleObject(source)) {
        for (const key in source) {
            if (isSimpleObject(source[key])) {
                if (!target[key])
                    Object.assign(target, { [key]: {} });
                mergeDeepOnTarget(target[key], source[key]);
            }
            else {
                Object.entries(source).forEach(entry => {
                    const [key, value] = entry;
                    if (!target[key] && target[key] !== null)
                        target[key] = value;
                });
            }
        }
    }
    return mergeDeepOnTarget(target, ...sources);
}
exports.mergeDeepOnTarget = mergeDeepOnTarget;
//# sourceMappingURL=objectUtils.js.map