"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteWhitespace = exports.getDigits = exports.isBlank = exports.isEmpty = exports.isString = void 0;
const lodash_1 = __importDefault(require("lodash"));
/**
 * Checks if `value` is classified as a String primitive or object.
 *
 * @param value The value to check.
 * @returns Returns true if value is correctly classified, else false.
 *
 * @example
 *
 * isString(null);
 * // => false
 * isString(undefined);
 * // => false
 * isString('');
 * // => true
 * isString(' ');
 * // => true
 * isString('test');
 * // => true
 * isString(new String());
 * // => true
 * isString(new String(''));
 * // => true
 * isString(new String(' '));
 * // => true
 * isString(new String('teste'));
 * // => true
 * isString(1);
 * // => false
 * isString({});
 * // => false
 * isString([]);
 * // => false
 */
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
function isString(value) {
    return lodash_1.default.isString(value);
}
exports.isString = isString;
/**
 * Checks if `value` is null, undefined or is classified as a String primitive or object and is empty ('').
 *
 * @param value The value to check.
 * @returns Returns true if `value` is null, undefined or is correctly classified and is empty (''), else false.
 *
 * @example
 *
 * isEmpty(null);
 * // => true
 * isEmpty(undefined);
 * // => true
 * isEmpty('');
 * // => true
 * isEmpty(' ');
 * // => false
 * isEmpty('test');
 * // => false
 * isEmpty(new String());
 * // => true
 * isEmpty(new String(''));
 * // => true
 * isEmpty(new String(' '));
 * // => false
 * isEmpty(new String('teste'));
 * // => false
 * isEmpty(1);
 * // => false
 * isEmpty({});
 * // => false
 * isEmpty([]);
 * // => false
 */
function isEmpty(value) {
    return value === null || value === undefined || isString(value) && value.length === 0;
}
exports.isEmpty = isEmpty;
/**
 * Checks if `value` is null, undefined or is classified as a String primitive or object and is empty ('') or whitespace only.
 *
 * @param value The value to check.
 * @returns Returns true if `value` is correctly classified and is empty ('') or whitespace only, else false.
 *
 * @example
 *
 * isBlank(null);
 * // => true
 * isBlank(undefined);
 * // => true
 * isBlank('');
 * // => true
 * isBlank(' ');
 * // => true
 * isBlank('test');
 * // => false
 * isBlank(new String());
 * // => true
 * isBlank(new String(''));
 * // => true
 * isBlank(new String(' '));
 * // => true
 * isBlank(new String('teste'));
 * // => false
 * isBlank(1);
 * // => false
 * isBlank({});
 * // => false
 * isBlank([]);
 * // => false
 */
function isBlank(value) {
    return value === null || value === undefined || isString(value) && !value.trim();
}
exports.isBlank = isBlank;
/**
 * Checks if `value` is classified as a String primitive or object, if yes then concatenate all the digits (0-9) in `value` and return it.
 *
 * @param value The value to check.
 * @returns Returns only digits (0-9) of `value`.
 * @example
 *
 * getDigits(null);
 * // => null
 * getDigits(undefined);
 * // => null
 * getDigits('');
 * // => ''
 * getDigits(' ');
 * // => ''
 * getDigits('test');
 * // => ''
 * getDigits('123.456.789-01');
 * // => '12345678901'
 * getDigits(new String());
 * // => ''
 * getDigits(new String(''));
 * // => ''
 * getDigits(new String(' '));
 * // => ''
 * getDigits(new String('teste'));
 * // => ''
 * getDigits(1);
 * // => null
 * getDigits({});
 * // => null
 * getDigits([]);
 * // => null
 */
function getDigits(value) {
    return isString(value) ? value.replace(new RegExp('[^0-9]', 'g'), '') : null;
}
exports.getDigits = getDigits;
/**
 * Deletes all whitespaces in `value` if it is classified as a String primitive or object, and return `value` without whitespaces.
 *
 * @param value The value to check.
 * @returns Returns the `value` without whitespaces, null if `value` is not correctly classified.
 * @example
 *
 * deleteWhitespace(null);
 * // => null
 * deleteWhitespace(undefined);
 * // => null
 * deleteWhitespace('');
 * // => ''
 * deleteWhitespace(' ');
 * // => ''
 * deleteWhitespace('test');
 * // => 'test'
 * deleteWhitespace('123.  789-01');
 * // => '123.789-01'
 * deleteWhitespace(new String());
 * // => ''
 * deleteWhitespace(new String(''));
 * // => ''
 * deleteWhitespace(new String(' '));
 * // => ''
 * deleteWhitespace(new String('te  st'));
 * // => 'test'
 * deleteWhitespace(1);
 * // => null
 * deleteWhitespace({});
 * // => null
 * deleteWhitespace([]);
 * // => null
 *
 */
function deleteWhitespace(value) {
    return isString(value) ? value.replace(/\s/g, '') : null;
}
exports.deleteWhitespace = deleteWhitespace;
//# sourceMappingURL=stringUtils.js.map